:orphan:

Welcome to Kivy
===============

Welcome to Kivy's documentation. Kivy is an open source software library for rapid
development of applications equipped with novel user interfaces, such as
multi-touch apps.

You are probably wondering why you'd be interested in using Kivy. There is
a document outlining our :ref:`philosophy` that we encourage you to read.

We recommend that you get started with :ref:`installation` and then head over to
the :ref:`quickstart` document. Besides the quickstart, there is also a more
detailed :ref:`architecture`.

If you want to contribute to Kivy, make sure to read :ref:`contributing`. If your
concern isn't addressed in the documentation, feel free to :ref:`contact`.

.. include:: contents.rst.inc


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

